@@ -15,7 +15,7 @@
 #' A learner for a classification support vector machine implemented in [e1071::svm()].
 #'
 #' @references
-#' Corinna Cortes and Vladimir Vapnik (1995).
+#' Corinna Cortes, Vladimir Vapnik (1995).
 #' Machine Learning 20: 273.
 #' \doi{10.1007/BF00994018}.
 #'
@@ -26,25 +26,25 @@
 LearnerClassifSVM = R6Class("LearnerClassifSVM", inherit = LearnerClassif,
   public = list(
     initialize = function() {
+      ps = ParamSet$new(list(
+        ParamFct$new("type", default = "C-classification", levels = c("C-classification", "nu-classification"), tags = "train"),
+        ParamDbl$new("cost", default = 1, lower = 0, tags = "train"), # requires = quote(type == "C-classification")),
+        ParamDbl$new("nu", default = 0.5, tags = "train"), # requires = quote(type == "nu-classification")),
+        ParamFct$new("kernel", default = "radial", levels = c("linear", "polynomial", "radial", "sigmoid"), tags = "train"),
+        ParamInt$new("degree", default = 3L, lower = 1L, tags = "train"), # requires = quote(kernel == "polynomial")),
+        ParamDbl$new("coef0", default = 0, tags = "train"), # requires = quote(kernel == "polynomial" || kernel == "sigmoid")),
+        ParamDbl$new("gamma", lower = 0, tags = "train"), # requires = quote(kernel != "linear")),
+        ParamDbl$new("cachesize", default = 40L, tags = "train"),
+        ParamDbl$new("tolerance", default = 0.001, lower = 0, tags = "train"),
+        ParamLgl$new("shrinking", default = TRUE, tags = "train"),
+        ParamInt$new("cross", default = 0L, lower = 0L, tags = "train"), # tunable = FALSE),
+        ParamLgl$new("fitted", default = TRUE, tags = "train"), # tunable = FALSE),
+        ParamUty$new("scale", default = TRUE, tags = "train") # , tunable = TRUE)
+      ))
+
       super$initialize(
         id = "classif.svm",
-        param_set = ParamSet$new(
-          params = list(
-            ParamFct$new(id = "type", default = "C-classification", levels = c("C-classification", "nu-classification"), tags = "train"),
-            ParamDbl$new(id = "cost", default = 1, lower = 0, tags = "train"), # requires = quote(type == "C-classification")),
-            ParamDbl$new(id = "nu", default = 0.5, tags = "train"), # requires = quote(type == "nu-classification")),
-            ParamFct$new(id = "kernel", default = "radial", levels = c("linear", "polynomial", "radial", "sigmoid"), tags = "train"),
-            ParamInt$new(id = "degree", default = 3L, lower = 1L, tags = "train"), # requires = quote(kernel == "polynomial")),
-            ParamDbl$new(id = "coef0", default = 0, tags = "train"), # requires = quote(kernel == "polynomial" || kernel == "sigmoid")),
-            ParamDbl$new(id = "gamma", lower = 0, tags = "train"), # requires = quote(kernel != "linear")),
-            ParamDbl$new(id = "cachesize", default = 40L, tags = "train"),
-            ParamDbl$new(id = "tolerance", default = 0.001, lower = 0, tags = "train"),
-            ParamLgl$new(id = "shrinking", default = TRUE, tags = "train"),
-            ParamInt$new(id = "cross", default = 0L, lower = 0L, tags = "train"), # tunable = FALSE),
-            ParamLgl$new(id = "fitted", default = TRUE, tags = "train"), # tunable = FALSE),
-            ParamUty$new(id = "scale", default = TRUE, tags = "train") # , tunable = TRUE)
-          )
-        ),
+        param_set = ps,
         predict_types = c("response", "prob"),
         feature_types = c("integer", "numeric"),
         properties = c("twoclass", "multiclass"),
