@@ -16,7 +16,7 @@
 #' Calls [ranger::ranger()] from package \CRANpkg{ranger}.
 #'
 #' @references
-#' Marvin N. Wright and Andreas Ziegler (2017).
+#' Marvin N. Wright, Andreas Ziegler (2017).
 #' ranger: A Fast Implementation of Random Forests for High Dimensional Data in C++ and R.
 #' Journal of Statistical Software, 77(1), 1-17.
 #' \doi{10.18637/jss.v077.i01}.
@@ -33,32 +33,32 @@
 LearnerRegrRanger = R6Class("LearnerRegrRanger", inherit = LearnerRegr,
   public = list(
     initialize = function() {
+      ps = ParamSet$new(list(
+        ParamInt$new("num.trees", default = 500L, lower = 1L, tags = c("train", "predict")),
+        ParamInt$new("mtry", lower = 1L, tags = "train"),
+        ParamFct$new("importance", levels = c("none", "impurity", "impurity_corrected", "permutation"), tags = "train"),
+        ParamLgl$new("write.forest", default = TRUE, tags = "train"),
+        ParamInt$new("min.node.size", default = 5L, lower = 1L, tags = "train"), # for probability == TRUE, def = 10
+        ParamLgl$new("replace", default = TRUE, tags = "train"),
+        ParamDbl$new("sample.fraction", lower = 0L, upper = 1L, tags = "train"), # for replace == FALSE, def = 0.632
+        # ParamDbl$new("class.weights", defaul = NULL, tags = "train"), #
+        ParamFct$new("splitrule", levels = c("variance", "extratrees", "maxstat"), default = "variance", tags = "train"),
+        ParamInt$new("num.random.splits", lower = 1L, default = 1L, tags = "train"), # requires = quote(splitrule == "extratrees")
+        ParamDbl$new("split.select.weights", lower = 0, upper = 1, tags = "train"),
+        ParamUty$new("always.split.variables", tags = "train"),
+        ParamFct$new("respect.unordered.factors", levels = c("ignore", "order", "partition"), default = "ignore", tags = "train"), # for splitrule == "extratrees", def = partition
+        ParamLgl$new("scale.permutation.importance", default = FALSE, tags = "train"), # requires = quote(importance == "permutation")
+        ParamLgl$new("keep.inbag", default = FALSE, tags = "train"),
+        ParamLgl$new("holdout", default = FALSE, tags = "train"), # FIXME: do we need this?
+        ParamInt$new("num.threads", lower = 1L, tags = c("train", "predict")),
+        ParamLgl$new("save.memory", default = FALSE, tags = "train"),
+        ParamLgl$new("verbose", default = TRUE, tags = c("train", "predict")),
+        ParamLgl$new("oob.error", default = TRUE, tags = "train")
+      ))
+
       super$initialize(
         id = "regr.ranger",
-        param_set = ParamSet$new(
-          params = list(
-            ParamInt$new(id = "num.trees", default = 500L, lower = 1L, tags = c("train", "predict")),
-            ParamInt$new(id = "mtry", lower = 1L, tags = "train"),
-            ParamFct$new(id = "importance", levels = c("none", "impurity", "impurity_corrected", "permutation"), tags = "train"),
-            ParamLgl$new(id = "write.forest", default = TRUE, tags = "train"),
-            ParamInt$new(id = "min.node.size", default = 5L, lower = 1L, tags = "train"), # for probability == TRUE, def = 10
-            ParamLgl$new(id = "replace", default = TRUE, tags = "train"),
-            ParamDbl$new(id = "sample.fraction", lower = 0L, upper = 1L, tags = "train"), # for replace == FALSE, def = 0.632
-            # ParamDbl$new(id = "class.weights", defaul = NULL, tags = "train"), #
-            ParamFct$new(id = "splitrule", levels = c("variance", "extratrees", "maxstat"), default = "variance", tags = "train"),
-            ParamInt$new(id = "num.random.splits", lower = 1L, default = 1L, tags = "train"), # requires = quote(splitrule == "extratrees")
-            ParamDbl$new(id = "split.select.weights", lower = 0, upper = 1, tags = "train"),
-            ParamUty$new(id = "always.split.variables", tags = "train"),
-            ParamFct$new(id = "respect.unordered.factors", levels = c("ignore", "order", "partition"), default = "ignore", tags = "train"), # for splitrule == "extratrees", def = partition
-            ParamLgl$new(id = "scale.permutation.importance", default = FALSE, tags = "train"), # requires = quote(importance == "permutation")
-            ParamLgl$new(id = "keep.inbag", default = FALSE, tags = "train"),
-            ParamLgl$new(id = "holdout", default = FALSE, tags = "train"), # FIXME: do we need this?
-            ParamInt$new(id = "num.threads", lower = 1L, tags = c("train", "predict")),
-            ParamLgl$new(id = "save.memory", default = FALSE, tags = "train"),
-            ParamLgl$new(id = "verbose", default = TRUE, tags = c("train", "predict")),
-            ParamLgl$new(id = "oob.error", default = TRUE, tags = "train")
-          )
-        ),
+        param_set = ps,
         predict_types = c("response", "se"),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         properties = c("weights", "importance", "oob_error"),
