@@ -1,7 +1,7 @@
 context("classif.svm")
 
 test_that("autotest", {
-  learner = LearnerClassifSVM$new()
+  learner = mlr3::lrn("classif.svm")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
