@@ -1,7 +1,7 @@
 context("regr.lm")
 
 test_that("autotest", {
-  learner = LearnerRegrLM$new()
+  learner = mlr3::lrn("regr.lm")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
