@@ -1,7 +1,7 @@
 context("regr.svm")
 
 test_that("autotest", {
-  learner = LearnerRegrSVM$new()
+  learner = mlr3::lrn("regr.svm")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
