@@ -1,9 +1,8 @@
 context("regr.xgboost")
 
 test_that("autotest", {
-  learner = LearnerRegrXgboost$new()
+  learner = mlr3::lrn("regr.xgboost", nrounds = 5L)
   expect_learner(learner)
-  learner$param_set$values = insert_named(learner$param_set$values, list(nrounds = 5L))
   result = run_autotest(learner)
   expect_true(result, info = result$error)
 })
